Module cache

Module cache 

Module implementing all things cache related

Modules

key_pointers
Implementation of key caching
page_pointers
Implementation of page pointer caching
page_states
Implementation of page state caching

Structs

Cache
A cache object of which the various things it keeps track of can be configured..
Uncached
A cache object implementing no cache.

Traits

CacheImpl
Trait for collapsing multiple generics into one. Wherever this trait is used, pass an instance of Cache.