Module key_pointers

Module key_pointers 

Implementation of key caching

Structs

ArrayKeyPointers
A cache that stores keys in an array. The array may be smaller than the amount of keys, but that will reduce performance.
HeapKeyPointers
A cache that stores keys in a vec. The vec may be smaller than the amount of keys, but that will reduce performance.

Traits

KeyPointersCache
A cache that caches pointers to keys