Module page_pointers

Module page_pointers 

Implementation of page pointer caching

Structs

ArrayPagePointers
A cache that stores page pointers in an array.
HeapPagePointers
A cache that stores page pointers in a vec.

Traits

PagePointersCache
A cache that caches which parts of the pages are written to already