Module page_states

Module page_states 

Implementation of page state caching

Structs

ArrayPageStates
A cache that stores page states in an array.
CalculatedPageStates
A cache that uses knowledge about the typical layout of pages.
HeapPageStates
A cache that stores page states in a vec.

Traits

PageStatesCache
A cache that caches the states for all pages