Cache

Struct Cache 

pub struct Cache<PAGE: PageStatesCache, POINTERS: PagePointersCache, KEYS: KeyPointersCache<KEY>, KEY = ()> { /* private fields */ }
A cache object of which the various things it keeps track of can be configured..

This cache has to be kept around and passed to every api call to the same memory region until the cache gets discarded.

Valid usecase:
Create cache 1 -> use 1 -> use 1 -> create cache 2 -> use 2 -> use 2

Invalid usecase:
Create cache 1 -> use 1 -> create cache 2 -> use 2 -> ❌ use 1 ❌

Make sure the page count is correct when it has to be provided. If the number is lower than the actual amount, the code will panic.

Implementations

Source

impl<PAGE: PageStatesCache, POINTERS: PagePointersCache, KEYS: KeyPointersCache<KEY>, KEY> Cache<PAGE, POINTERS, KEYS, KEY>

pub fn new( page_states: PAGE, page_pointers: POINTERS, key_pointers: KEYS, ) -> Self

Create a new cache object from the given subcaches

Source

impl<KEY> Cache<Uncached, Uncached, Uncached, KEY>

pub const fn new_uncached() -> Self

Create a new cache object that doesn’t cache anything