pub enum PageState {
Closed,
PartialOpen,
Open,
}Expand description
The state of a page
Variants
Closed
This page was fully written and has now been sealed
PartialOpen
This page has been written to, but may have some space left over
Open
This page is fully erased