pub trait PostcardValue<'a>: Serialize + Deserialize<'a> { }Expand description
Marker trait for types that will be serialized using postcard.
Implement this trait on a type to enable automatically using postcard to serialize and deserialize it.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".