pub trait StorageItemError: Debug {
    // Required method
    fn is_buffer_too_small(&self) -> bool;
}
A trait that the storage item error needs to implement

Required Methods

source

fn is_buffer_too_small(&self) -> bool

Returns true if the error indicates that the buffer is too small to contain the storage item

Implementors