Module queue

Module queue 

Implementation of the queue logic.

Modules

buffered
RAM-buffered wrapper for QueueStorage.

Structs

QueueConfig
Configuration for a queue
QueueIterator
An iterator-like interface for peeking into data stored in flash with the option to pop it.
QueueIteratorEntry
An entry in the iteration over the queue flash
QueueStorage
A fifo queue storage