pub enum QueueConfigError {
StartRangeNotAtPageBoundary,
EndRangeNotAtPageBoundary,
RangeTooSmall,
PagesTooSmall,
WordSizeTooLarge,
}Expand description
Error for QueueConfig constructor
Variants
StartRangeNotAtPageBoundary
The start range address is not a multiple of the erase size
EndRangeNotAtPageBoundary
The end range address is not a multiple of the erase size
RangeTooSmall
The queue needs at least 1 page to operate, but got less
PagesTooSmall
The pages of the flash are too small to work with
WordSizeTooLarge
The word size of the flash is bigger than [MAX_WORD_SIZE]