pub async fn peek_many<S: NorFlash, CI: CacheImpl>(
    flash: &mut S,
    flash_range: Range<u32>,
    cache: CI
) -> Result<PeekIterator<'_, S, CI>, Error<S::Error>>
Peek at the data from oldest to newest.

If you also want to remove the data use pop_many.

Returns an iterator-like type that can be used to peek into the data.