Function sequential_storage::queue::pop

source ·
pub fn pop<S: MultiwriteNorFlash, const CAP: usize>(
    flash: &mut S,
    flash_range: Range<u32>
) -> Result<Option<ArrayVec<u8, CAP>>, Error<S::Error>>
Pop the oldest data from the queue.

If you don’t want to remove the data use peek.

The given CAP determines the buffer size with which is read. An error is returned if the oldest data is longer than CAP.