pub struct Cache<PAGE: PageStatesCache, POINTERS: PagePointersCache, KEYS: KeyPointersCache<KEY>, KEY = ()> { /* private fields */ }Expand description
A cache object of which the various things it keeps track of can be configured..
This cache has to be kept around and passed to every api call to the same memory region until the cache gets discarded.
Valid usecase:
Create cache 1 -> use 1 -> use 1 -> create cache 2 -> use 2 -> use 2
Invalid usecase:
Create cache 1 -> use 1 -> create cache 2 -> use 2 -> ❌ use 1 ❌
Make sure the page count is correct when it has to be provided. If the number is lower than the actual amount, the code will panic.
Implementations
Sourceimpl<PAGE: PageStatesCache, POINTERS: PagePointersCache, KEYS: KeyPointersCache<KEY>, KEY> Cache<PAGE, POINTERS, KEYS, KEY>
impl<PAGE: PageStatesCache, POINTERS: PagePointersCache, KEYS: KeyPointersCache<KEY>, KEY> Cache<PAGE, POINTERS, KEYS, KEY>