pub const fn item_overhead_size<S: NorFlash>() -> u32Expand description
Get the minimal overhead size per stored item for the given flash type.
The associated data of each item is additionally padded to a full flash word size, but that’s not part of this number.
This means the full item length is returned number + (data length).next_multiple_of(S::WORD_SIZE).