pub fn fetch_item<I: StorageItem, S: NorFlash>(
    flash: &mut S,
    flash_range: Range<u32>,
    search_key: I::Key
) -> Result<Option<I>, MapError<I::Error, S::Error>>
Get a storage item from the flash. Only the last stored item of the given key is returned.

If no value with the key is found, None is returned.