Store a key-value pair into flash memory.
It will overwrite the last value that has the same key.
The flash needs to be at least 2 pages long.
The data buffer must be long enough to hold the longest serialized data of your Key + Value types combined,
rounded up to flash word alignment.
You are required to, on a given flash range, use the same Key type every time. You are allowed to usemultiple Value types. See the module-level docs for more information about this.
Also watch out for using integers. This function will take any integer and it’s easy to pass the wrong type.